==> pandoc-crossref-0.3.19-117-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.19
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.19-8ekJDTtSkjkKTcKgfaj0B2-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.19-8ekJDTtSkjkKTcKgfaj0B2-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  934c50f2455780fba765d50765d03b89
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.19-8ekJDTtSkjkKTcKgfaj0B2-pandoc-crossref-internal

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.2-95OdNmNpLKa9cNDp3ZlqO5 directory-1.3.7.1
    filepath-1.4.2.2 microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-ghc-0.4.15.1-CjElCeEmbPg9RMtJsMDsV0
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    pandoc-3.2-EoPKBUIR4TVL3hBaNjenu3
    pandoc-types-1.23.1-7qhMcAsOl2E7hqDAjcd2Na
    syb-0.7.3-GzxvBIT7N6LHXGQxqlBVFk template-haskell-2.19.0.0
    text-2.0.2 utility-ht-0.0.17.2-BaXmqz7C091FCLqTeD1Lcq

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.19
visibility:           public
id:                   pandoc-crossref-0.3.19-G14DL9Qvj1W8R3261tqjrg
key:                  pandoc-crossref-0.3.19-G14DL9Qvj1W8R3261tqjrg
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  afd02754125ef8b0aa7fb8e922453c0f
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.19-G14DL9Qvj1W8R3261tqjrg
depends:
    base-4.17.2.1 mtl-2.2.2 pandoc-3.2-EoPKBUIR4TVL3hBaNjenu3
    pandoc-crossref-0.3.19-8ekJDTtSkjkKTcKgfaj0B2-pandoc-crossref-internal
    pandoc-types-1.23.1-7qhMcAsOl2E7hqDAjcd2Na text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.19-118-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.19
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.19-6swvIDQn5dpKzcc9xpm4pz-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.19-6swvIDQn5dpKzcc9xpm4pz-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  b6890d22da9558c66f59b5bd7dce972c
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.19-6swvIDQn5dpKzcc9xpm4pz-pandoc-crossref-internal

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.2-GUUW0V5lisrJnDmYs4YZIH directory-1.3.7.1
    filepath-1.4.2.2 microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-ghc-0.4.15.1-CjElCeEmbPg9RMtJsMDsV0
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    pandoc-3.2-9nPBsXUnEBBFnrWtEL8Z10
    pandoc-types-1.23.1-K06ZkCBa4PnEZfDQl4Mn1O
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P template-haskell-2.19.0.0
    text-2.0.2 utility-ht-0.0.17.2-EdtnUt8ynzSBuI4KEWKvqW

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.19
visibility:           public
id:                   pandoc-crossref-0.3.19-IB7uuxQH6c44Ct3YYkJTd2
key:                  pandoc-crossref-0.3.19-IB7uuxQH6c44Ct3YYkJTd2
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  84124fef0a2231f5bec598c7d90e6bbb
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.19-IB7uuxQH6c44Ct3YYkJTd2
depends:
    base-4.17.2.1 mtl-2.2.2 pandoc-3.2-9nPBsXUnEBBFnrWtEL8Z10
    pandoc-crossref-0.3.19-6swvIDQn5dpKzcc9xpm4pz-pandoc-crossref-internal
    pandoc-types-1.23.1-K06ZkCBa4PnEZfDQl4Mn1O text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
